==> haskell-indexed-profunctors-0.1.1-3-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-indexed-profunctors.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 indexed-profunctors
version:              0.1.1
visibility:           public
id:                   indexed-profunctors-0.1.1-GQTIGxqDJ6jFqxn3qvYbGz
key:                  indexed-profunctors-0.1.1-GQTIGxqDJ6jFqxn3qvYbGz
license:              BSD-3-Clause
maintainer:           optics@well-typed.com
author:               Adam Gundry, Andres Löh, Andrzej Rybczak, Oleg Grenrus
synopsis:             Utilities for indexed profunctors
description:
    This package contains basic definitions related to indexed profunctors.  These
    are primarily intended as internal utilities to support the @optics@ and
    @generic-lens@ package families.

category:             Data, Optics, Lenses, Profunctors
abi:                  9568a11ddcffb0b57939d989b39bd2e0
exposed:              True
exposed-modules:      Data.Profunctor.Indexed
import-dirs:          /usr/lib/ghc-9.0.1/site-local/indexed-profunctors-0.1.1
library-dirs:         /usr/lib/ghc-9.0.1/site-local/indexed-profunctors-0.1.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.0.1/indexed-profunctors-0.1.1
hs-libraries:         HSindexed-profunctors-0.1.1-GQTIGxqDJ6jFqxn3qvYbGz
depends:              base-4.15.0.0
haddock-interfaces:
    /usr/share/doc/haskell-indexed-profunctors/html/indexed-profunctors.haddock

haddock-html:         /usr/share/doc/haskell-indexed-profunctors/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-indexed-profunctors-0.1.1-4-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-indexed-profunctors.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 indexed-profunctors
version:              0.1.1
visibility:           public
id:                   indexed-profunctors-0.1.1-5fGRVjLEHI0IPX9k0oVbdA
key:                  indexed-profunctors-0.1.1-5fGRVjLEHI0IPX9k0oVbdA
license:              BSD-3-Clause
maintainer:           optics@well-typed.com
author:               Adam Gundry, Andres Löh, Andrzej Rybczak, Oleg Grenrus
synopsis:             Utilities for indexed profunctors
description:
    This package contains basic definitions related to indexed profunctors.  These
    are primarily intended as internal utilities to support the @optics@ and
    @generic-lens@ package families.

category:             Data, Optics, Lenses, Profunctors
abi:                  bcbf0cdeb154fad0ceead00e1110177d
exposed:              True
exposed-modules:      Data.Profunctor.Indexed
import-dirs:          /usr/lib/ghc-9.0.2/site-local/indexed-profunctors-0.1.1
library-dirs:         /usr/lib/ghc-9.0.2/site-local/indexed-profunctors-0.1.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.0.2/indexed-profunctors-0.1.1
hs-libraries:         HSindexed-profunctors-0.1.1-5fGRVjLEHI0IPX9k0oVbdA
depends:              base-4.15.1.0
haddock-interfaces:
    /usr/share/doc/haskell-indexed-profunctors/html/indexed-profunctors.haddock

haddock-html:         /usr/share/doc/haskell-indexed-profunctors/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
